import { ref } from '@vue/composition-api';
export function useConst(initialValue) {
    // Use useRef to store the value because it's the least expensive built-in hook that works here
    // (we could also use `const [value] = React.useState(initialValue)` but that's more expensive
    // internally due to reducer handling which we don't need)
    var _ref = ref();
    if (_ref.value === undefined) {
        // Box the value in an object so we can tell if it's initialized even if the initializer
        // returns/is undefined
        _ref.value = {
            value: typeof initialValue === 'function' ? initialValue() : initialValue,
        };
    }
    return _ref.value.value;
}
//# sourceMappingURL=useConst.js.map